==> cbol-1.5.tgz: cbol-1.5/sdict.php <==
<?php
 require("config.php");
 require("dbconfig.php");
 require("lang.php");
 /**** @ܼ ********/
  //W
 $PROGNAME="sdict.php";
/************* GET ܼ ***************/
  $N=$_REQUEST['N'];//d 0Gtorrey 1:naves
  if ($GBCODE==1)
        $keyword=trim(tranbig5($_REQUEST['keyword']));
  else
        $keyword=trim($_REQUEST['keyword']);      //d߸
   $keyword=str_replace('\'','\\\'',$keyword);
 if ($GBCODE==0)
        echo "<meta http-equiv=\"Content-Type\" CONTENT=\"text/html; charset=big5\">";
 else
        echo "<meta http-equiv=\"Content-Type\" CONTENT=\"text/html; charset=gb2312\">";

 if ($N) //¬
 {
  $dictname="bdb";
  $dictname1="hfhl";
  $SNUM="hsnum";
 }
 else //s
 {
  $dictname="thayer";
  $dictname1="gfhl";
  $SNUM="gsnum";
 }
 //if (get_magic_quotes_gpc()==0) $keyword=addslashes($keyword);
 $QUERY="select  $dictname.$SNUM,$dictname.txt,$dictname1.txt from $dictname, $dictname1 where $dictname.txt like '%$keyword%' and $dictname.$SNUM=$dictname1.$SNUM"; 
 if ($updatemode)
   $QUERY1="select  $SNUM,txt,username from $dictname1 where txt like '%$keyword%'"; 
 else
 	$QUERY1="select  $SNUM,txt from $dictname1 where txt like '%$keyword%'"; 
  //TableXSOѼ
 $tabout="border=1";
  //Jܼ
  //d߸ƪY
 $THEADER=array("s","rq");
  //C@
 $PGNUM=50;
 // Primary Key	
 $PKEY="oid";
 $KEYCOLOR="\"#FF0000\"";
 $COLOR="\"#000000\"";
 
 $db_conn=db_connect("host=localhost dbname=$DBNAME password=123");
 db_set_encoding($db_conn,"BIG5");
 /******** }ldƮw ********/
 $result=db_exec($db_conn,$QUERY);
 $result1=db_exec($db_conn,$QUERY1);
 if (!$result){
                        echogb("Ʈwd߿~AO $QUERY !");
                        exit;
 }
 if (!$result1){
                        echogb("Ʈwd߿~AO $QUERY1 !");
                        exit;
 }
 $numrow=db_NumRows($result);  
 $numrow1=db_NumRows($result1);  
 /****** ȶȬOB˵ *********/
 if ($numrow>1500)
   {
   	echogb("@ $numrow AƤӦhFAЭקd߱AdI");
	exit;
   }
 if ($numrow1>1500)
   {
   	echogb("@ $numrow1 AƤӦhFAЭקd߱AdI");
	exit;
   }
 /******** LX ********/
echogb("<FONT COLOR=$COLOR><center>^r $numrow <br><table $tabout>\n");
      for ($i=0;$i<$numrow;$i++)
      {
        $ARAW=db_fetch_row($result,$i); //Ū@O
        $special="<a href=\"s.php?N=$N&k=$ARAW[0]\">$ARAW[0]</a>";//SrBz
        if (strlen($ARAW[2])==0) $spec="";
        else $spec="½ĶLF";
        echogb("<tr><td align=center>$special</td><td>$spec</td></tr>\n"); //s
       }
     echo "</table>\n";
 echogb("<FONT COLOR=$COLOR><center>r $numrow1 <br><table $tabout>\n");
      for ($i=0;$i<$numrow1;$i++)
      {
        $ARAW1=db_fetch_row($result1,$i); //Ū@O
          $special="<a href=\"s.php?N=$N&k=$ARAW1[0]\">$ARAW1[0]</a>";//SrBz
        echogb("<tr><td align=center>$special</td></tr>\n"); //s
       }
     echo "</table>\n";
     echogb("<a href=\"$RETURNADD1\">sd</a></center><br>\n");
?>

==> cbol-1.7.tgz: cbol-1.7/sdict.php <==
<?php
 require("config.php");
 require("dbconfig.php");
 require("lang.php");
 /**** @ܼ ********/
  //W
 $PROGNAME="sdict.php";
/************* GET ܼ ***************/
  $N=(int) $_REQUEST['N'];//d 0Gtorrey 1:naves
  if ($GBCODE==1)
        $keyword=trim(tranbig5($_REQUEST['keyword']));
  else
        $keyword=trim($_REQUEST['keyword']);      //d߸
   $keyword=str_replace('\'','\\\'',$keyword);
 if ($GBCODE==0)
        echo "<meta http-equiv=\"Content-Type\" CONTENT=\"text/html; charset=big5\">";
 else
        echo "<meta http-equiv=\"Content-Type\" CONTENT=\"text/html; charset=gb2312\">";

 if ($N) //¬
 {
  $dictname="bdb";
  $dictname1="hfhl";
  $SNUM="hsnum";
 }
 else //s
 {
  $dictname="thayer";
  $dictname1="gfhl";
  $SNUM="gsnum";
 }
 //if (get_magic_quotes_gpc()==0) $keyword=addslashes($keyword);
 $QUERY="select  $dictname.$SNUM,$dictname.txt,$dictname1.txt from $dictname, $dictname1 where $dictname.txt like '%$keyword%' and $dictname.$SNUM=$dictname1.$SNUM"; 
 if ($updatemode)
   $QUERY1="select  $SNUM,txt,username from $dictname1 where txt like '%$keyword%'"; 
 else
 	$QUERY1="select  $SNUM,txt from $dictname1 where txt like '%$keyword%'"; 
  //TableXSOѼ
 $tabout="border=1";
  //Jܼ
  //d߸ƪY
 $THEADER=array("s","rq");
  //C@
 $PGNUM=50;
 // Primary Key	
 $PKEY="oid";
 $KEYCOLOR="\"#FF0000\"";
 $COLOR="\"#000000\"";
 
 $db_conn=db_connect("host=localhost dbname=$DBNAME password=123");
 db_set_encoding($db_conn,"BIG5");
 /******** }ldƮw ********/
 $result=db_exec($db_conn,$QUERY);
 $result1=db_exec($db_conn,$QUERY1);
 if (!$result){
                        echogb("Ʈwd߿~AO $QUERY !");
                        exit;
 }
 if (!$result1){
                        echogb("Ʈwd߿~AO $QUERY1 !");
                        exit;
 }
 $numrow=db_NumRows($result);  
 $numrow1=db_NumRows($result1);  
 /****** ȶȬOB˵ *********/
 if ($numrow>1500)
   {
   	echogb("@ $numrow AƤӦhFAЭקd߱AdI");
	exit;
   }
 if ($numrow1>1500)
   {
   	echogb("@ $numrow1 AƤӦhFAЭקd߱AdI");
	exit;
   }
 /******** LX ********/
echogb("<FONT COLOR=$COLOR><center>^r $numrow <br><table $tabout>\n");
      for ($i=0;$i<$numrow;$i++)
      {
        $ARAW=db_fetch_row($result,$i); //Ū@O
        $special="<a href=\"s.php?N=$N&k=$ARAW[0]\">$ARAW[0]</a>";//SrBz
        if (strlen($ARAW[2])==0) $spec="";
        else $spec="½ĶLF";
        echogb("<tr><td align=center>$special</td><td>$spec</td></tr>\n"); //s
       }
     echo "</table>\n";
 echogb("<FONT COLOR=$COLOR><center>r $numrow1 <br><table $tabout>\n");
      for ($i=0;$i<$numrow1;$i++)
      {
        $ARAW1=db_fetch_row($result1,$i); //Ū@O
          $special="<a href=\"s.php?N=$N&k=$ARAW1[0]\">$ARAW1[0]</a>";//SrBz
        echogb("<tr><td align=center>$special</td></tr>\n"); //s
       }
     echo "</table>\n";
     echogb("<a href=\"$RETURNADD1\">sd</a></center><br>\n");
?>
